==> kubernetes-model-policy-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/HostPortRangeFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class HostPortRangeFluentImpl<A extends io.fabric8.kubernetes.api.model.policy.v1beta1.HostPortRangeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.policy.v1beta1.HostPortRangeFluent<A>{
  public HostPortRangeFluentImpl() {
  }
  public HostPortRangeFluentImpl(io.fabric8.kubernetes.api.model.policy.v1beta1.HostPortRange instance) {
    this.withMax(instance.getMax()); 
    this.withMin(instance.getMin()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer max;
  private java.lang.Integer min;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getMax() {
    return this.max;
  }
  public A withMax(java.lang.Integer max) {
    this.max=max; return (A) this;
  }
  public java.lang.Boolean hasMax() {
    return this.max != null;
  }
  public java.lang.Integer getMin() {
    return this.min;
  }
  public A withMin(java.lang.Integer min) {
    this.min=min; return (A) this;
  }
  public java.lang.Boolean hasMin() {
    return this.min != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HostPortRangeFluentImpl that = (HostPortRangeFluentImpl) o;
    if (max != null ? !max.equals(that.max) :that.max != null) return false;
    if (min != null ? !min.equals(that.min) :that.min != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(max,  min,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-policy-5.12.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/HostPortRangeFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class HostPortRangeFluentImpl<A extends io.fabric8.kubernetes.api.model.policy.v1beta1.HostPortRangeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.policy.v1beta1.HostPortRangeFluent<A>{
  public HostPortRangeFluentImpl() {
  }
  public HostPortRangeFluentImpl(io.fabric8.kubernetes.api.model.policy.v1beta1.HostPortRange instance) {
    this.withMax(instance.getMax()); 
    this.withMin(instance.getMin()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer max;
  private java.lang.Integer min;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getMax() {
    return this.max;
  }
  public A withMax(java.lang.Integer max) {
    this.max=max; return (A) this;
  }
  public java.lang.Boolean hasMax() {
    return this.max != null;
  }
  public java.lang.Integer getMin() {
    return this.min;
  }
  public A withMin(java.lang.Integer min) {
    this.min=min; return (A) this;
  }
  public java.lang.Boolean hasMin() {
    return this.min != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HostPortRangeFluentImpl that = (HostPortRangeFluentImpl) o;
    if (max != null ? !max.equals(that.max) :that.max != null) return false;
    if (min != null ? !min.equals(that.min) :that.min != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(max,  min,  additionalProperties,  super.hashCode());
  }
  
}
